@@ -1,5 +1,9 @@
 TYPE_MESSAGES = {
     'invalid': "Got value `{0}` of type `{1}`.  Value must be of type(s): `{2}`",
+    'invalid_header_type': (
+        "Invalid type for header: `{0}`.  Must be one of 'string', 'number', "
+        "'integer', 'boolean', or 'array'."
+    ),
 }
 
 FORMAT_MESSAGES = {
